from setuptools import setup, find_packages

setup(
    name='moshe-my-sample-package',
    version='0.1',
    packages=find_packages(),
    install_requires=[],
    test_suite='tests',
    author='Moshe Eliya',
    author_email='',
)
